//
//  GradeView.swift
//  SwiftDataGrades
//
//  Created by Joe Gregg on 10/18/24.
//

import Foundation
import SwiftData
import SwiftUI

struct GradeView: View {
    @Environment(\.modelContext) private var modelContext
    @Query private var quizzes: [Quiz]
    @Query private var students: [Student]
    @State var quiz : Quiz?
    @State var student : Student?
    var body: some View {
        if quizzes.count == 0 {
            Text("No quizzes available to display")
        } else if students.count == 0 {
            Text("No students available to display")
        } else {
            VStack {
                Picker(selection: $quiz,label:Text("Select a quiz:")) {
                    ForEach(quizzes) { q in
                        Text(q.name).tag(q.self as Quiz?)
                    }
                }
                Picker(selection: $student,label:Text("Select a student:")) {
                    ForEach(students) { s in
                        Text("\(s.first_name) \(s.last_name)").tag(s.self as Student?)
                    }
                }
                Spacer()
                if let q = quiz, let s = student {
                    GradeDetailView(student: s,quiz: q)
                }
                Spacer()
            }.onAppear {
                quiz = quizzes.first
                student = students.first
            }
        }
    }
    
}
